@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.apigateway_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -145,7 +156,7 @@ class ApiGatewayServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -181,9 +192,9 @@ class ApiGatewayServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ApiGatewayServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the api gateway service client.
@@ -227,11 +238,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def list_gateways(
         self,
-        request: Union[apigateway.ListGatewaysRequest, dict] = None,
+        request: Optional[Union[apigateway.ListGatewaysRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGatewaysAsyncPager:
         r"""Lists Gateways in a given project and location.
@@ -264,7 +275,7 @@ class ApiGatewayServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.ListGatewaysRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.ListGatewaysRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.ListGateways
             parent (:class:`str`):
@@ -342,11 +353,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def get_gateway(
         self,
-        request: Union[apigateway.GetGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.GetGatewayRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Gateway:
         r"""Gets details of a single Gateway.
@@ -378,7 +389,7 @@ class ApiGatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.GetGatewayRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.GetGatewayRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.GetGateway
             name (:class:`str`):
@@ -448,13 +459,13 @@ class ApiGatewayServiceAsyncClient:
 
     async def create_gateway(
         self,
-        request: Union[apigateway.CreateGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.CreateGatewayRequest, dict]] = None,
         *,
-        parent: str = None,
-        gateway: apigateway.Gateway = None,
-        gateway_id: str = None,
+        parent: Optional[str] = None,
+        gateway: Optional[apigateway.Gateway] = None,
+        gateway_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Gateway in a given project and
@@ -490,13 +501,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.CreateGatewayRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.CreateGatewayRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.CreateGateway
             parent (:class:`str`):
@@ -601,12 +612,12 @@ class ApiGatewayServiceAsyncClient:
 
     async def update_gateway(
         self,
-        request: Union[apigateway.UpdateGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.UpdateGatewayRequest, dict]] = None,
         *,
-        gateway: apigateway.Gateway = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        gateway: Optional[apigateway.Gateway] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Gateway.
@@ -639,13 +650,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.UpdateGatewayRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.UpdateGatewayRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.UpdateGateway
             gateway (:class:`google.cloud.apigateway_v1.types.Gateway`):
@@ -746,11 +757,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def delete_gateway(
         self,
-        request: Union[apigateway.DeleteGatewayRequest, dict] = None,
+        request: Optional[Union[apigateway.DeleteGatewayRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Gateway.
@@ -780,13 +791,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.DeleteGatewayRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.DeleteGatewayRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.DeleteGateway
             name (:class:`str`):
@@ -880,11 +891,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def list_apis(
         self,
-        request: Union[apigateway.ListApisRequest, dict] = None,
+        request: Optional[Union[apigateway.ListApisRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApisAsyncPager:
         r"""Lists Apis in a given project and location.
@@ -917,7 +928,7 @@ class ApiGatewayServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.ListApisRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.ListApisRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.ListApis
             parent (:class:`str`):
@@ -995,11 +1006,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def get_api(
         self,
-        request: Union[apigateway.GetApiRequest, dict] = None,
+        request: Optional[Union[apigateway.GetApiRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.Api:
         r"""Gets details of a single Api.
@@ -1031,7 +1042,7 @@ class ApiGatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.GetApiRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.GetApiRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.GetApi
             name (:class:`str`):
@@ -1097,13 +1108,13 @@ class ApiGatewayServiceAsyncClient:
 
     async def create_api(
         self,
-        request: Union[apigateway.CreateApiRequest, dict] = None,
+        request: Optional[Union[apigateway.CreateApiRequest, dict]] = None,
         *,
-        parent: str = None,
-        api: apigateway.Api = None,
-        api_id: str = None,
+        parent: Optional[str] = None,
+        api: Optional[apigateway.Api] = None,
+        api_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Api in a given project and location.
@@ -1134,13 +1145,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.CreateApiRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.CreateApiRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.CreateApi
             parent (:class:`str`):
@@ -1244,12 +1255,12 @@ class ApiGatewayServiceAsyncClient:
 
     async def update_api(
         self,
-        request: Union[apigateway.UpdateApiRequest, dict] = None,
+        request: Optional[Union[apigateway.UpdateApiRequest, dict]] = None,
         *,
-        api: apigateway.Api = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        api: Optional[apigateway.Api] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Api.
@@ -1278,13 +1289,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.UpdateApiRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.UpdateApiRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.UpdateApi
             api (:class:`google.cloud.apigateway_v1.types.Api`):
@@ -1382,11 +1393,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def delete_api(
         self,
-        request: Union[apigateway.DeleteApiRequest, dict] = None,
+        request: Optional[Union[apigateway.DeleteApiRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Api.
@@ -1416,13 +1427,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.DeleteApiRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.DeleteApiRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.DeleteApi
             name (:class:`str`):
@@ -1516,11 +1527,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def list_api_configs(
         self,
-        request: Union[apigateway.ListApiConfigsRequest, dict] = None,
+        request: Optional[Union[apigateway.ListApiConfigsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListApiConfigsAsyncPager:
         r"""Lists ApiConfigs in a given project and location.
@@ -1553,7 +1564,7 @@ class ApiGatewayServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.ListApiConfigsRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.ListApiConfigsRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.ListApiConfigs
             parent (:class:`str`):
@@ -1631,11 +1642,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def get_api_config(
         self,
-        request: Union[apigateway.GetApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.GetApiConfigRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> apigateway.ApiConfig:
         r"""Gets details of a single ApiConfig.
@@ -1667,7 +1678,7 @@ class ApiGatewayServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.GetApiConfigRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.GetApiConfigRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.GetApiConfig
             name (:class:`str`):
@@ -1734,13 +1745,13 @@ class ApiGatewayServiceAsyncClient:
 
     async def create_api_config(
         self,
-        request: Union[apigateway.CreateApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.CreateApiConfigRequest, dict]] = None,
         *,
-        parent: str = None,
-        api_config: apigateway.ApiConfig = None,
-        api_config_id: str = None,
+        parent: Optional[str] = None,
+        api_config: Optional[apigateway.ApiConfig] = None,
+        api_config_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a new ApiConfig in a given project and
@@ -1772,13 +1783,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.CreateApiConfigRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.CreateApiConfigRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.CreateApiConfig
             parent (:class:`str`):
@@ -1881,12 +1892,12 @@ class ApiGatewayServiceAsyncClient:
 
     async def update_api_config(
         self,
-        request: Union[apigateway.UpdateApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.UpdateApiConfigRequest, dict]] = None,
         *,
-        api_config: apigateway.ApiConfig = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        api_config: Optional[apigateway.ApiConfig] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single ApiConfig.
@@ -1915,13 +1926,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.UpdateApiConfigRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.UpdateApiConfigRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.UpdateApiConfig
             api_config (:class:`google.cloud.apigateway_v1.types.ApiConfig`):
@@ -2020,11 +2031,11 @@ class ApiGatewayServiceAsyncClient:
 
     async def delete_api_config(
         self,
-        request: Union[apigateway.DeleteApiConfigRequest, dict] = None,
+        request: Optional[Union[apigateway.DeleteApiConfigRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single ApiConfig.
@@ -2054,13 +2065,13 @@ class ApiGatewayServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.apigateway_v1.types.DeleteApiConfigRequest, dict]):
+            request (Optional[Union[google.cloud.apigateway_v1.types.DeleteApiConfigRequest, dict]]):
                 The request object. Request message for
                 ApiGatewayService.DeleteApiConfig
             name (:class:`str`):
@@ -2159,14 +2170,9 @@ class ApiGatewayServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-api-gateway",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("ApiGatewayServiceAsyncClient",)
