@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import field_mask_pb2  # type: ignore
@@ -839,7 +841,7 @@ class GetApiConfigRequest(proto.Message):
 
         Values:
             CONFIG_VIEW_UNSPECIFIED (0):
-
+                No description available.
             BASIC (1):
                 Do not include configuration source files.
             FULL (2):
